@@ -3,7 +3,7 @@
 ######################################################################
 #
 # Copyright 2004, Danga Interactice, Inc.
-# Copyright 2005, Six Apart, Ltd.
+# Copyright 2005-2006, Six Apart, Ltd.
 #
 
 package Perlbal::Service;
@@ -51,6 +51,7 @@ use fields (
             'always_trusted', # bool; if true, always trust upstreams
             'enable_reproxy', # bool; if true, advertise that server will reproxy files and/or URLs
             'reproxy_cache_maxsize', # int; maximum number of reproxy results to be cached. (0 is disabled and default)
+            'client_sndbuf_size',    # int: bytes for SO_SNDBUF
 
             # Internal state:
             'waiting_clients',         # arrayref of clients waiting for backendhttp conns
@@ -483,6 +484,13 @@ our $tunables = {
         check_role => "reverse_proxy",
     },
 
+    'client_sndbuf_size' => {
+        des => "How large to set the client's socket SNDBUF.",
+        default => 0,
+        check_type => "size",
+        check_role => '*',
+    },
+
 
 };
 sub autodoc_get_tunables { return $tunables; }
